package com.emato.cus.supervise.biz.acqGoodsMoveSchedule.up;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domain.WmsAcqGoodsMove;
import com.emato.cus.supervise.domainCus.CusAcqGoodsMove05;
import com.emato.cus.supervise.domainOms.OmsProductInfo;
import com.google.common.collect.Lists;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-03 15:40
 */
@Component
public class AcqGoodsMoveUpDataConversion implements DataConversion {

    private final  static Logger logger = LoggerFactory.getLogger(AcqGoodsMoveUpDataConversion.class);

    /**
     * 货物库位移动数据
     *
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("货物库位移动数据开始转换oms，wms 组装cus数据===========================");
        List<WmsAcqGoodsMove> wmsList = (List<WmsAcqGoodsMove>) params.get("wmsList");

        List<OmsProductInfo> productInfoList = (List<OmsProductInfo>) params.get("productInfoList");
        final Map<String,OmsProductInfo> omsProductInfoMap = productInfoList.stream().collect(Collectors.toMap(k->k.getSkuNo(), v->v));

        List<CusAcqGoodsMove05> cusAcqGoodsMove05List = Lists.newArrayList();
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

        for (int i = 0; i < wmsList.size(); i++) {
            // #20190521001
            // 未作try catch 导致一个sku数据异常，全部终止
            try {
                WmsAcqGoodsMove wmsAcqGoodsMove = wmsList.get(i);

                OmsProductInfo omsProductInfo = omsProductInfoMap.get(wmsAcqGoodsMove.getSkuNo());

                logger.debug("当前转换的sku为: {}", omsProductInfo.getSkuNo());

                CusAcqGoodsMove05 cusAcqGoodsMove05 = new CusAcqGoodsMove05();
                cusAcqGoodsMove05.setId(wmsAcqGoodsMove.getId());
                if("上架".equals(wmsAcqGoodsMove.getTaskType())){
                    cusAcqGoodsMove05.setShelfLoadTime(wmsAcqGoodsMove.getCreated());
                }
                if("批量拣选".equals(wmsAcqGoodsMove.getTaskType())){
                    cusAcqGoodsMove05.setShelfUnloadTime(wmsAcqGoodsMove.getCreated());
                }
                cusAcqGoodsMove05.setTargetSeatNo(wmsAcqGoodsMove.getTargetSeatNo());
                cusAcqGoodsMove05.setOriginSeatNo(wmsAcqGoodsMove.getOriginSeatNo());
                cusAcqGoodsMove05.setGoodsName(wmsAcqGoodsMove.getGoodsName());

    //            cusAcqGoodsMove05.setCodeTs(wmsAcqGoodsMove.getCodeTs());

                cusAcqGoodsMove05.setSkuNo(wmsAcqGoodsMove.getSkuNo());
                cusAcqGoodsMove05.setGoodsId(wmsAcqGoodsMove.getGoodsId());
                cusAcqGoodsMove05.setgUnit(wmsAcqGoodsMove.getgUnit());
                cusAcqGoodsMove05.setgQty(wmsAcqGoodsMove.getgQty());
                cusAcqGoodsMove05.setLegalUnit(wmsAcqGoodsMove.getLegalUnit());
                cusAcqGoodsMove05.setLegalQty(wmsAcqGoodsMove.getLegalQty());
                cusAcqGoodsMove05.setGoodsModel(wmsAcqGoodsMove.getGoodsModel());
                cusAcqGoodsMove05.setLocalEmsNo(Dict.localEmsNo);
                cusAcqGoodsMove05.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqGoodsMove05.setStoreUscCode(Dict.storeUscCode);
                cusAcqGoodsMove05.setStoreCustomsCode(Dict.storeCustomsCode);
                cusAcqGoodsMove05.setStoreCode(Dict.storeCode);
                cusAcqGoodsMove05.setCreateTime(LocalDateTime.now());
                cusAcqGoodsMove05.setCreaterSn("1");
                cusAcqGoodsMove05.setModerSn("1");
                cusAcqGoodsMove05.setModTime(LocalDateTime.now());
                cusAcqGoodsMove05.setLegalQty(omsProductInfo.getLegalQyt());
                cusAcqGoodsMove05.setLegalUnit(omsProductInfo.getLegalUnit());
                cusAcqGoodsMove05.setGoodsModel(omsProductInfo.getGoodsModel());
                cusAcqGoodsMove05.setCodeTs(omsProductInfo.getCodeTs());
                cusAcqGoodsMove05List.add(cusAcqGoodsMove05);
            }catch (Exception e){
                logger.error("货物库位移动组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("货物库位移动转换oms，wms 组装cus数据结束===========================");
        return cusAcqGoodsMove05List;
    }
}
